pub trait Report {
// Required method
fn report(&self, span: Span);
}Expand description
A reporter consumes Zipkin spans and reports them.
For example, the reporter may log the span information to a file, or send it over the network to a collection service.
Required Methods
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".